@@ -65,8 +65,8 @@ class TestCollect(testtools.TestCase):
                 'heatclient': test_heat.FakeHeatClient(self)
             }
         }
-        collect.__main__(args=fake_args,
-                         collector_kwargs_map=collector_kwargs_map)
+        return collect.__main__(args=fake_args,
+                                collector_kwargs_map=collector_kwargs_map)
 
     def _fake_popen_call_main(self, occ_args):
         calls = []
@@ -75,7 +75,7 @@ class TestCollect(testtools.TestCase):
             calls.append(proc_args)
             return dict(returncode=0)
         self.useFixture(fixtures.FakePopen(capture_popen))
-        self._call_main(occ_args)
+        self.assertEqual(0, self._call_main(occ_args))
         return calls
 
     def test_main(self):
@@ -119,8 +119,10 @@ class TestCollect(testtools.TestCase):
             'server'
         ]
         calls = self._fake_popen_call_main(occ_args)
-        proc_args = calls[0]
-        self.assertEqual(expected_cmd, proc_args['args'])
+        # The Python 3 platform module makes a popen call, filter this out
+        proc_calls = [call for call in calls if call['args'] == expected_cmd]
+        self.assertEqual(len(proc_calls), 1)
+        proc_args = proc_calls[0]
         for test_dir in (cache_dir, backup_cache_dir):
             list_path = os.path.join(test_dir.path, 'os_config_files.json')
             with open(list_path) as list_file:
@@ -194,7 +196,7 @@ class TestCollect(testtools.TestCase):
             calls.append(proc_args)
             return dict(returncode=1)
         self.useFixture(fixtures.FakePopen(capture_popen))
-        self._call_main(occ_args)
+        self.assertEqual(1, self._call_main(occ_args))
         for test_dir in (cache_dir, backup_cache_dir):
             cache_contents = os.listdir(test_dir.path)
             last_files = [n for n in cache_contents if n.endswith('last')]
